#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp
version:              2.2.0.0
visibility:           public
id:                   lsp-2.2.0.0-6LZ7pOCDgZ2AzF4Z9mZdB3
key:                  lsp-2.2.0.0-6LZ7pOCDgZ2AzF4Z9mZdB3
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:             Haskell library for the Microsoft Language Server Protocol
description:
    An implementation of the types, and basic message server to
    allow language implementors to support the Language Server
    Protocol for their specific language.

    An example of this is for Haskell via the Haskell Language
    Server, at https://github.com/haskell/haskell-language-server

category:             Development
abi:                  1126656f0b57a8fe9ff0741a2c06a29b
exposed:              True
exposed-modules:
    Language.LSP.Diagnostics, Language.LSP.Logging,
    Language.LSP.Protocol.Capabilities from lsp-types-2.0.2.0-xmc6WCw8XEoIKXtrPVFU:Language.LSP.Protocol.Capabilities,
    Language.LSP.Protocol.Lens from lsp-types-2.0.2.0-xmc6WCw8XEoIKXtrPVFU:Language.LSP.Protocol.Lens,
    Language.LSP.Protocol.Message from lsp-types-2.0.2.0-xmc6WCw8XEoIKXtrPVFU:Language.LSP.Protocol.Message,
    Language.LSP.Protocol.Types from lsp-types-2.0.2.0-xmc6WCw8XEoIKXtrPVFU:Language.LSP.Protocol.Types,
    Language.LSP.Server, Language.LSP.VFS

hidden-modules:
    Language.LSP.Server.Control Language.LSP.Server.Core
    Language.LSP.Server.Processing

import-dirs:          /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp
hs-libraries:         HSlsp-2.2.0.0-6LZ7pOCDgZ2AzF4Z9mZdB3
depends:
    aeson-2.2.1.0-7GSyYSIvS9RDNhRsQEr5uY
    async-2.2.6-8zdvXX2Zsrb75FFkoyfONv
    attoparsec-0.14.4-4MFXwr0rahYLyPRJgVlAQG base-4.18.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.6-5Hx4M7Tck694Pit0LVcvQK
    containers-0.6.7 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1
    hashable-1.4.7.0-7IXYIAIJ1Hk6CRw3icGaw3
    lens-5.3.4-Cku8S685vSJvKBRP2wLkQ
    lens-aeson-1.2.3-93Qon8vWlEV53HYoqN2xk5
    lsp-types-2.0.2.0-xmc6WCw8XEoIKXtrPVFU mtl-2.3.1
    prettyprinter-1.7.1-AIpSGHD2G4p9DIqum0FCg8
    random-1.2.1.3-1X0iumC2zGHGNw6mS2AiRE
    row-types-1.0.1.2-GVywpg0ndquKQRKjxYz33
    sorted-list-0.2.3.1-3mf2bfDqITKDsG7xcRm3ux stm-2.5.1.0
    temporary-1.3-4A2o6mPXKpYBClKvGulSYQ text-2.0.2
    text-rope-0.3-Ap9tNAElwvo1DE9nQl4uAS transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-KOOMDe69vyW5LNgLyOaup0
    uuid-1.3.16-CY9auhPU9VmHzSvUPwoEAU

haddock-interfaces:   /usr/share/doc/haskell-lsp/html/lsp.haddock
haddock-html:         /usr/share/doc/haskell-lsp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

